summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStefan Kost <ensonic@users.sf.net>2010-09-13 11:17:34 +0300
committerStefan Kost <ensonic@users.sf.net>2010-09-13 11:18:25 +0300
commit8ef7e46d24063674895c15b6081bee405d0e87c5 (patch)
tree06405510034da9af3b0404354495eb8451f494ea
parentef5a78e71feeacabb40041ec409babde0b509188 (diff)
docs: fix warnings pointed out by gtk-doc
-rw-r--r--docs/gst/gstreamer-sections.txt2
-rw-r--r--gst/gstcaps.c8
-rw-r--r--gst/gstdatetime.c12
-rw-r--r--gst/gstelement.c2
-rw-r--r--gst/gstelementfactory.h4
-rw-r--r--gst/gstpad.c4
-rw-r--r--gst/gsttaglist.h1
7 files changed, 19 insertions, 14 deletions
diff --git a/docs/gst/gstreamer-sections.txt b/docs/gst/gstreamer-sections.txt
index 596123d55..2f08eed19 100644
--- a/docs/gst/gstreamer-sections.txt
+++ b/docs/gst/gstreamer-sections.txt
@@ -1975,7 +1975,7 @@ gst_query_set_buffering_range
gst_query_parse_buffering_range
gst_query_add_buffering_range
gst_query_get_n_buffering_ranges
-gst_query_parse_buffering_range
+gst_query_parse_nth_buffering_range
gst_query_new_uri
gst_query_parse_uri
diff --git a/gst/gstcaps.c b/gst/gstcaps.c
index dd3303e2f..00fbc851f 100644
--- a/gst/gstcaps.c
+++ b/gst/gstcaps.c
@@ -540,7 +540,7 @@ gst_caps_remove_and_get_structure (GstCaps * caps, guint idx)
/**
* gst_caps_steal_structure:
* @caps: the #GstCaps to retrieve from
- * @idx: Index of the structure to retrieve
+ * @index: Index of the structure to retrieve
*
* Retrieves the stucture with the given index from the list of structures
* contained in @caps. The caller becomes the owner of the returned structure.
@@ -550,15 +550,15 @@ gst_caps_remove_and_get_structure (GstCaps * caps, guint idx)
* Since: 0.10.30
*/
GstStructure *
-gst_caps_steal_structure (GstCaps * caps, guint idx)
+gst_caps_steal_structure (GstCaps * caps, guint index)
{
g_return_val_if_fail (caps != NULL, NULL);
g_return_val_if_fail (IS_WRITABLE (caps), NULL);
- if (G_UNLIKELY (idx >= caps->structs->len))
+ if (G_UNLIKELY (index >= caps->structs->len))
return NULL;
- return gst_caps_remove_and_get_structure (caps, idx);
+ return gst_caps_remove_and_get_structure (caps, index);
}
static gboolean
diff --git a/gst/gstelement.c b/gst/gstelement.c
index 1ffc6423f..f4e38f9fa 100644
--- a/gst/gstelement.c
+++ b/gst/gstelement.c
@@ -1254,7 +1254,7 @@ gst_element_class_set_documentation_uri (GstElementClass * klass,
/**
* gst_element_class_set_icon_name:
* @klass: class to set details for
- * @uri: name of an icon
+ * @name: name of an icon
*
* Elements that bridge to certain other products can include an icon of that
* used product. Application can show the icon in menus/selectors to help
diff --git a/gst/gstelementfactory.h b/gst/gstelementfactory.h
index 4d06edb7f..9f744053c 100644
--- a/gst/gstelementfactory.h
+++ b/gst/gstelementfactory.h
@@ -224,6 +224,7 @@ typedef guint64 GstElementFactoryListType;
/**
* GST_ELEMENT_FACTORY_TYPE_ANY:
+ *
* Elements of any of the defined GST_ELEMENT_FACTORY_LIST types
*
* Since: 0.10.31
@@ -232,6 +233,7 @@ typedef guint64 GstElementFactoryListType;
/**
* GST_ELEMENT_FACTORY_TYPE_MEDIA_ANY:
+ *
* Elements matching any of the defined GST_ELEMENT_FACTORY_TYPE_MEDIA types
*
* Note: Do not use this if you wish to not filter against any of the defined
@@ -244,6 +246,7 @@ typedef guint64 GstElementFactoryListType;
/**
* GST_ELEMENT_FACTORY_TYPE_VIDEO_ENCODER:
+ *
* All encoders handling video or image media types
*
* Since: 0.10.31
@@ -252,6 +255,7 @@ typedef guint64 GstElementFactoryListType;
/**
* GST_ELEMENT_FACTORY_TYPE_AUDIO_ENCODER:
+ *
* All encoders handling audio media types
*
* Since: 0.10.31
diff --git a/gst/gstpad.c b/gst/gstpad.c
index 52909fab5..c3316849b 100644
--- a/gst/gstpad.c
+++ b/gst/gstpad.c
@@ -2022,12 +2022,12 @@ done:
* can cause severe issues. Refer to the documentation of #GstPadLinkCheck
* for more information.
*
+ * MT Safe.
+ *
* Returns: A result code indicating if the connection worked or
* what went wrong.
*
* Since: 0.10.30
- *
- * MT Safe.
*/
GstPadLinkReturn
gst_pad_link_full (GstPad * srcpad, GstPad * sinkpad, GstPadLinkCheck flags)
diff --git a/gst/gsttaglist.h b/gst/gsttaglist.h
index 127ff6c4e..19ea3498a 100644
--- a/gst/gsttaglist.h
+++ b/gst/gsttaglist.h
@@ -469,6 +469,7 @@ gboolean gst_tag_list_get_buffer_index (const GstTagList * list,
#define GST_TAG_DATE "date"
/**
* GST_TAG_DATE_TIME:
+ *
* date and time the data was created (#GstDateTime structure)
*
* Since: 0.10.31
diff --git a/gst/gstdatetime.c b/gst/gstdatetime.c
index 85b3ff414..e02ea259a 100644
--- a/gst/gstdatetime.c
+++ b/gst/gstdatetime.c
@@ -25,7 +25,7 @@
#include "gstdatetime.h"
/**
- * SECTION:gst-date-time
+ * SECTION:gstdatetime
* @title: GstDateTime
* @short_description: A date, time and timezone structure
*
@@ -299,24 +299,24 @@ gst_date_time_get_time_zone_offset (const GstDateTime * datetime)
/**
* gst_date_time_new_from_unix_epoch:
* @t: seconds from the Unix epoch
*
* Creates a new #GstDateTime using the time since Jan 1, 1970 specified by @t.
* The #GstDateTime is in the local timezone.
*
* Return value: the newly created #GstDateTime
*
* Since: 0.10.31
*/
GstDateTime *
-gst_date_time_new_from_unix_epoch (gint64 t)
+gst_date_time_new_from_unix_epoch (gint64 secs)
{
GstDateTime *dt;
struct tm tm;
time_t tt;
memset (&tm, 0, sizeof (tm));
- tt = (time_t) t;
+ tt = (time_t) secs;
#ifdef HAVE_LOCALTIME_R
localtime_r (&tt, &tm);
@@ -299,24 +299,24 @@ gst_date_time_get_time_zone_offset (const GstDateTime * datetime)
/**
* gst_date_time_new_from_unix_epoch:
- * @t: seconds from the Unix epoch
+ * @secs: seconds from the Unix epoch
*
@@ -299,24 +299,24 @@ gst_date_time_get_time_zone_offset (const GstDateTime * datetime)
*
- * Creates a new #GstDateTime using the time since Jan 1, 1970 specified by @t.
- * The #GstDateTime is in the local timezone.
+ * Creates a new #GstDateTime using the time since Jan 1, 1970 specified by
+ * @secs. The #GstDateTime is in the local timezone.
*
* Return value: the newly created #GstDateTime